summaryrefslogtreecommitdiffstats
path: root/kcontrol/krdb
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/krdb')
-rw-r--r--kcontrol/krdb/ad/README2
-rw-r--r--kcontrol/krdb/krdb.cpp4
2 files changed, 3 insertions, 3 deletions
diff --git a/kcontrol/krdb/ad/README b/kcontrol/krdb/ad/README
index a051becc7..830ba77b4 100644
--- a/kcontrol/krdb/ad/README
+++ b/kcontrol/krdb/ad/README
@@ -49,7 +49,7 @@ The krdb utility works by putting your current KDE color
and font scheme into preprocessor statements, concatenating
the specially written application default files and using
xrdb -merge to write to RESOURCE_MANAGER. Thus it gives a
-simple way to make non-KDE applications fit in with the
+simple way to make non-TDE applications fit in with the
desktop.
krdb now comes with a set of general purpose configuration
diff --git a/kcontrol/krdb/krdb.cpp b/kcontrol/krdb/krdb.cpp
index 60ee13bfe..d966af4cf 100644
--- a/kcontrol/krdb/krdb.cpp
+++ b/kcontrol/krdb/krdb.cpp
@@ -3,7 +3,7 @@
**
** KRDB - puts current KDE color scheme into preprocessor statements
** cats specially written application default files and uses xrdb -merge to
** write to RESOURCE_MANAGER. Thus it gives a simple way to make non-KDE
** applications fit in with the desktop
**
** Copyright (C) 1998 by Mark Donohoe
@@ -345,7 +345,7 @@ static void createGtkrc( bool exportColors, const TQColorGroup& cg, int version
"#\n"
"# If you do not want KDE to override your GTK settings, select\n"
"# Appearance & Themes -> Colors in the Control Center and disable the checkbox\n"
- "# \"Apply colors to non-KDE applications\"\n"
+ "# \"Apply colors to non-TDE applications\"\n"
"#\n"
"#\n").arg(TQDateTime::currentDateTime().toString());
@@ -3,7 +3,7 @@
** KRDB - puts current KDE color scheme into preprocessor statements
** cats specially written application default files and uses xrdb -merge to
-** write to RESOURCE_MANAGER. Thus it gives a simple way to make non-KDE
+** write to RESOURCE_MANAGER. Thus it gives a simple way to make non-TDE
** applications fit in with the desktop
**